==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ListWorkflowRunActionRepetitionExpressionTracesPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ListWorkflowRunActionRepetitionExpressionTracesPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property actionName The workflow action name.
 * @property name Site name.
 * @property repetitionName The workflow repetition.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 * @property runName The workflow run name.
 * @property workflowName The workflow name.
 */
public data class ListWorkflowRunActionRepetitionExpressionTracesPlainArgs(
    public val actionName: String,
    public val name: String,
    public val repetitionName: String,
    public val resourceGroupName: String,
    public val runName: String,
    public val workflowName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.ListWorkflowRunActionRepetitionExpressionTracesPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.ListWorkflowRunActionRepetitionExpressionTracesPlainArgs =
        com.pulumi.azurenative.web.inputs.ListWorkflowRunActionRepetitionExpressionTracesPlainArgs.builder()
            .actionName(actionName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .repetitionName(repetitionName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .runName(runName.let({ args0 -> args0 }))
            .workflowName(workflowName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListWorkflowRunActionRepetitionExpressionTracesPlainArgs].
 */
@PulumiTagMarker
public class ListWorkflowRunActionRepetitionExpressionTracesPlainArgsBuilder internal constructor() {
    private var actionName: String? = null

    private var name: String? = null

    private var repetitionName: String? = null

    private var resourceGroupName: String? = null

    private var runName: String? = null

    private var workflowName: String? = null

    /**
     * @param value The workflow action name.
     */
    @JvmName("oejfdwclxinlbmau")
    public suspend fun actionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.actionName = mapped
    }

    /**
     * @param value Site name.
     */
    @JvmName("hwomglpjvygvpqks")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The workflow repetition.
     */
    @JvmName("wgkqxebplhbhdcff")
    public suspend fun repetitionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.repetitionName = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("gepmrphehwukrtep")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The workflow run name.
     */
    @JvmName("rwkjilouluaemlus")
    public suspend fun runName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.runName = mapped
    }

    /**
     * @param value The workflow name.
     */
    @JvmName("ypgntrlfkborngfn")
    public suspend fun workflowName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workflowName = mapped
    }

    internal fun build(): ListWorkflowRunActionRepetitionExpressionTracesPlainArgs =
        ListWorkflowRunActionRepetitionExpressionTracesPlainArgs(
            actionName = actionName ?: throw PulumiNullFieldException("actionName"),
            name = name ?: throw PulumiNullFieldException("name"),
            repetitionName = repetitionName ?: throw PulumiNullFieldException("repetitionName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            runName = runName ?: throw PulumiNullFieldException("runName"),
            workflowName = workflowName ?: throw PulumiNullFieldException("workflowName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ListWorkflowRunActionRepetitionExpressionTracesPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ListWorkflowRunActionRepetitionExpressionTracesPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property actionName The workflow action name.
 * @property name Site name.
 * @property repetitionName The workflow repetition.
 * @property resourceGroupName Name of the resource group to which the resource belongs.
 * @property runName The workflow run name.
 * @property workflowName The workflow name.
 */
public data class ListWorkflowRunActionRepetitionExpressionTracesPlainArgs(
    public val actionName: String,
    public val name: String,
    public val repetitionName: String,
    public val resourceGroupName: String,
    public val runName: String,
    public val workflowName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.web.inputs.ListWorkflowRunActionRepetitionExpressionTracesPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.web.inputs.ListWorkflowRunActionRepetitionExpressionTracesPlainArgs =
        com.pulumi.azurenative.web.inputs.ListWorkflowRunActionRepetitionExpressionTracesPlainArgs.builder()
            .actionName(actionName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .repetitionName(repetitionName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .runName(runName.let({ args0 -> args0 }))
            .workflowName(workflowName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListWorkflowRunActionRepetitionExpressionTracesPlainArgs].
 */
@PulumiTagMarker
public class ListWorkflowRunActionRepetitionExpressionTracesPlainArgsBuilder internal constructor() {
    private var actionName: String? = null

    private var name: String? = null

    private var repetitionName: String? = null

    private var resourceGroupName: String? = null

    private var runName: String? = null

    private var workflowName: String? = null

    /**
     * @param value The workflow action name.
     */
    @JvmName("vmsxnvkxryotjjku")
    public suspend fun actionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.actionName = mapped
    }

    /**
     * @param value Site name.
     */
    @JvmName("wgqreiurxuciehur")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The workflow repetition.
     */
    @JvmName("nudamcingpsqeiep")
    public suspend fun repetitionName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.repetitionName = mapped
    }

    /**
     * @param value Name of the resource group to which the resource belongs.
     */
    @JvmName("wbvpnvolhlneaecw")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The workflow run name.
     */
    @JvmName("supcolafgqkukqbv")
    public suspend fun runName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.runName = mapped
    }

    /**
     * @param value The workflow name.
     */
    @JvmName("khfvxgdiuhxhnqjp")
    public suspend fun workflowName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workflowName = mapped
    }

    internal fun build(): ListWorkflowRunActionRepetitionExpressionTracesPlainArgs =
        ListWorkflowRunActionRepetitionExpressionTracesPlainArgs(
            actionName = actionName ?: throw PulumiNullFieldException("actionName"),
            name = name ?: throw PulumiNullFieldException("name"),
            repetitionName = repetitionName ?: throw PulumiNullFieldException("repetitionName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            runName = runName ?: throw PulumiNullFieldException("runName"),
            workflowName = workflowName ?: throw PulumiNullFieldException("workflowName"),
        )
}
